//------------------------------------------------------------------------------
//
//  npplot.c
//  npe
//
//  Created by Shane Saxon on 2/19/10.
//  Copyright Saxon Digital 2010. All rights reserved.
//
//------------------------------------------------------------------------------


#include "npplot.h"

#include <stdlib.h>

#include "../npctrl.h"



void InitPlotGrid (NPgridPtr grid);


//------------------------------------------------------------------------------
void npInitPlot (void* dataRef)
{
	int i = 0;

	pData data = (pData) dataRef;

	for (i=0; i < kPlotMaximum; i++)
		data->io.plot[i] = NULL;
}


//------------------------------------------------------------------------------
void npClosePlot(void* dataRef)
{
	
}


//------------------------------------------------------------------------------
void npPlotNew (int plotType, NPplotPtr plot)
{
}

void InitPlot (NPplotPtr plot)
{
	plot->type			= kPlotDefault;		//plot type, point, pin, cam, video
	plot->data			= NULL;				//plot type specific data

	plot->parent		= NULL;				//parent plot, binary tree of plots
	plot->branchL		= NULL;				//the left daughter branch
	plot->branchR		= NULL;				//the right daughter branch

	plot->channel.x		= kChannelNull;		//channel to use for x,y,z points
	plot->channel.y		= kChannelNull;
	plot->channel.z		= kChannelNull;
	
	plot->channelIndex.x = 0;				//last updated channel index
	plot->channelIndex.y = 0;
	plot->channelIndex.z = 0;

	plot->averageType.x	= kAverageNull;		//averaging type applied to data
	plot->averageType.y	= kAverageNull;
	plot->averageType.z	= kAverageNull;
	
	plot->sampleInterval.x = 1;				//the interval to be averaged
	plot->sampleInterval.y = 1;
	plot->sampleInterval.z = 1;

	plot->rotate.angle	= 0.0f;				//orientation
	plot->rotate.x		= 0.0f;
	plot->rotate.y		= 0.0f;
	plot->rotate.z		= 1.0f;
	
	plot->scale.x		= 1.0f;				//scale plot XYZ
	plot->scale.y		= 1.0f;
	plot->scale.z		= 1.0f;
	
	plot->translate.x	= 0.0f;				//location relative to plotOrigin
	plot->translate.y	= 0.0f;
	plot->translate.z	= 0.0f;

	plot->plotOrigin.x	= 0.0f;				//origin relative to parent origin
	plot->plotOrigin.y	= 0.0f;
	plot->plotOrigin.z	= 0.0f;

	plot->rotateRate.angle	= 0.0f;			//rotation rate
	plot->rotateRate.x		= 0.0f;
	plot->rotateRate.y		= 0.0f;
	plot->rotateRate.z		= 0.0f;
	
	plot->scaleRate.x	= 0.0f;				//scale rate 
	plot->scaleRate.y	= 0.0f;
	plot->scaleRate.z	= 0.0f;

	plot->translateRate.x = 0.0f;			//pans the location of the plot, pronunciar en Espanol, lol
	plot->translateRate.y = 0.0f;
	plot->translateRate.z = 0.0f;

	plot->surfaceType	= kSurfaceNull;		//FFT layers, terrain, sphere...
	plot->shaderType	= kShadingFlat;		//wire, flat, gouraud, phong

	plot->lineWidth		= 0.0f;				//draws lines, zero for off
	plot->pointSize		= 0.0f;				//draws dots, zero for off
	plot->circle		= 0.0f;				//draw circle at current data point

	plot->colorIndex	= 0;
	
	plot->color.r		= 255;				//color assigned to new data
	plot->color.g		= 127;				//default to yellow
	plot->color.b		= 127;
	plot->color.a		= 255;				//fully opaque

	plot->colorFade		= false;

	plot->hide			= false;			//hide the plot, data stays active
	plot->freeze		= false;			//freezes data and physics updates
	plot->center		= false;			//centers to plotOrigin
	plot->centerPerGrid	= false;			//centers in gridSpace increments

	plot->autoZoom.x	= false;			//scales plot to fit screen
	plot->autoZoom.y	= false;
	plot->autoZoom.z	= false;

	plot->scroll		= false;			//scroll right to left
	
	plot->triggerOnHi.x	= false;			//triggers are multipurpose
	plot->triggerOnHi.y	= false;
	plot->triggerOnHi.x	= false;

	plot->triggerOnLow.x = false;
	plot->triggerOnLow.y = false;
	plot->triggerOnLow.z = false;
	
	plot->triggerLevelHi.x = 0.0f;
	plot->triggerLevelHi.y = 0.0f;
	plot->triggerLevelHi.z = 0.0f;

	plot->triggerLevelLow.x = 0.0f;
	plot->triggerLevelLow.y = 0.0f;
	plot->triggerLevelLow.z = 0.0f;

	plot->triggerCommand = kCtrlCommandNull;	//execute ctrlCommand upon trigger
	
	plot->proximity.x	= false;			//used for collision engine 
	plot->proximity.y	= false;
	plot->proximity.z	= false;
	
	plot->proximityRadius.x = 0.0f;
	plot->proximityRadius.y = 0.0f;
	plot->proximityRadius.z = 0.0f;

	plot->drawCurrentValue.x = false;		//draw current values as text
	plot->drawCurrentValue.x = false;
	plot->drawCurrentValue.x = false;

	plot->drawTranslate.x = false;			//draw translate as text
	plot->drawTranslate.x = false;
	plot->drawTranslate.x = false;
	
	plot->drawScale.x	= false;			//draw scale as text
	plot->drawScale.x	= false;
	plot->drawScale.x	= false;
	
	plot->drawRotate.x	= false;			//draw rotation as text
	plot->drawRotate.y	= false;
	plot->drawRotate.z	= false;
}


//-----------------------------------------------------------------------------
void InitPlotPoints (NPpointsPtr data)
{
	data->vertexArray	= NULL;				//the array of data points
	data->colorArray	= NULL;				//each point gets color assigned
	data->vertexCount	= 0;				//number of points in the plot
	data->arrayIndex	= 0;				//current vertex index in the array
}


//-----------------------------------------------------------------------------
void InitPlotPin (NPpinPtr data)
{
	data->textureRef = NULL;						//texture assigned to element
}


// cameras can be GL scene cameras or real-world cameras
// video is attached as a daughter of the recPlot
//-----------------------------------------------------------------------------
void InitPlotCamera (NPcameraPtr data)
{
	data->textureID		= NULL;				//texture ID in GL

	data->targetCenter.x = 0.0f;			//object tracking in Global coord
	data->targetCenter.y = 0.0f;
	data->targetCenter.z = 0.0f;
	data->zoomFOV		= 35.0f;			//35mm, 70mm...

	data->format		= kVideoFormatNull;		//320p, 480i, 720p, 4K full app
	data->width			= 1;					//in pixels
	data->height		= 1;
	data->aspectRatio	= 1.0f;				//1.0, 1.333, 1.777, 1.85, 2.25... 
	data->colorSpace	= kColorSpaceNull;	//8, 12bit, YUV, RGBA, XYZ, CMYK...
	data->fps			= 59.94f;			// 15, 24, 29.97, 30, 59.94, 120...

	data->aperture		= 1.0f;					//F stop
	data->exposure		= 0.01f;				//in seconds
	data->sensorType	= kCameraSensorNull;	//3CCD, Debayer pattern...
}


//-----------------------------------------------------------------------------
void InitPlotVideo (NPvideoPtr data)
{
	data->textureID		= NULL;				//texture ID in GL

	data->format		= kVideoFormatNull;		//320p, 480i, 720p, 4K full app
	data->width			= 1;					//in pixels
	data->height		= 1;
	data->aspectRatio	= 1.0f;				//1.0, 1.333, 1.777, 1.85, 2.25... 
	data->colorSpace	= kColorSpaceNull;	//8, 12bit, YUV, RGBA, XYZ, CMYK...
	data->fps			= 59.94f;			// 15, 24, 29.97, 30, 59.94, 120...

	data->bias.x		= 0.0f;				//brightness shift, 0.0 no change
	data->bias.y		= 0.0f;
	data->bias.z		= 0.0f;
	data->gain.x		= 1.0f;				//color multiplier, 1.0 no change
	data->gain.y		= 1.0f;
	data->gain.z		= 1.0f;
}


//------------------------------------------------------------------------------
void InitPlotGrid (NPgridPtr grid)
{
	grid->segments.x = 10;
	grid->segments.y = 10;
	grid->segments.z = 0;
	grid->size.x = 10.0f;
	grid->size.y = 10.0f;
	grid->size.z = 10.0f;
}


//------------------------------------------------------------------------------
void npPlotDelete (void* dataRef)
{
	
}


